@@ -14,7 +14,7 @@ def divide(num1, num2):
   return num1/num2
 
 def squareroot(num1):
-  return num1/num1
+  return num1**num1
 
 def stringlettercount(String):
   stringletters = len(String)
